#
# spec file for package simple-scan
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           simple-scan
Version:        44.0
Release:        1.2
Summary:        Simple Scanning Utility
License:        GPL-3.0-or-later
Group:          System/GUI/GNOME
URL:            https://gitlab.gnome.org/GNOME/simple-scan
Source0:        https://download.gnome.org/sources/simple-scan/44/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  sane-backends-devel
BuildRequires:  vala >= 0.22.0
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(colord)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.38
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(gusb) >= 0.2.7
BuildRequires:  pkgconfig(libhandy-1) >= 1.6.0
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libwebpmux)
BuildRequires:  pkgconfig(packagekit-glib2) >= 1.1.5
BuildRequires:  pkgconfig(zlib)
Requires:       xdg-utils

%description
Simple Scan is an easy-to-use application, designed to let users connect
their scanner and quickly have the image/document in an appropriate
format.

Simple Scan is basically a frontend for SANE - which is the same backend
as XSANE uses. This means that all existing scanners will work and the
interface is well tested.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc NEWS README.md
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.SimpleScan.gschema.xml
%{_mandir}/man1/%{name}.1%{?ext_man}
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/simple-scan.appdata.xml
%{_datadir}/icons/hicolor/*/apps/*.svg

%files lang -f %{name}.lang

%changelog
* Sun Mar 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Add shortcut for Preferences (Ctrl+comma: Opens the preferences
    window).
  + Add buttons to change orientation of even/odd pages - usecase
    for Reversing Automatic Document Feeder (RADF) scanners.
  + Fix image size after cropping.
  + Updated translations.
* Wed Sep 21 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.5:
  + Updated translations.
* Tue Apr 19 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 42.1
  + Clarify project license.
  + Updated translations.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Skip virtual devices when detecting scanners.
  + Add support for postprocessing scripts.
  + Save Window state to user's .config folder instead of user's
    .cache folder.
  + Updates 'About' dialog to match with other GNOME apps.
  + Delete autosave records after creating new document.
  + Fix replacing underscore with space.
  + Fix autosave of Page Side property.
  + Add the device name to the label if there are several identical
    models.
  + Fix incorrect scan button tooltips.
  + Updated translations.
- Drop patches fixed upstream:
  + da6626debe00be1a0660f30cf2bf7629186c01d5.patch
  + 200.patch
* Tue Feb  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add da6626debe00be1a0660f30cf2bf7629186c01d5.patch: Fix build
  with meson 0.61.0 and newer.
* Mon Jan 17 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add 200.patch: Fix accessibility conflict of constant and its
  value. Fixes build with vala 0.55.x.
* Thu Dec 23 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.7:
  + Fix replacing underscore with space in scanner names.
  + Delete autosave records after creating new document.
  + Add the device name to the label if there are several identical
    models.
  + Fix autosave of Page Side property.
* Sun Oct 31 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.6:
  + Add duplex scanning support for Canon DR-C240.
  + Add missing centered ADF source option from Brother driver.
  + Updated translations.
* Thu Sep 23 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.5:
  + Fix automatic size detection on Brother scanners.
  + Updated translations.
* Tue May 25 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.1:
  + Updated translations.
* Wed Mar 24 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Re-released with correct version number.
* Sat Mar 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40:
  + Updated translations.
* Fri Feb 26 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.beta:
  + Don't repeat vendor name in the device name.
  + GNOME 40 consistency updates.
  + Fix crop size after decreasing page size.
  + UI fixes: change crop icon, improve layout of buttons.
  + Add redetect button to device list.
  + Add new resolution 200 DPI.
  + Add zero second delay for Multiple Pages from FlatBed.
  + Display an error, when no documents found in the feeder.
  + Rename 'Start again' button to 'New document'.
  + Fix crash on lexmark backend.
  + Updated translations.
- Add pkgconfig(libhandy-1) BuildRequires: new dependency.
* Tue Dec  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.2:
  + Add new text resolution 200 dpi.
  + Fix crash when scanning on Lexmark MFP.
  + Display an error, when no documents found in the feeder during
    start scanning.
  + Do not use is_inhibited() as it is not reliable, check the
    cookie value instead.
  + Updated translations.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Updated translations.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Sat Sep  5 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Display error message if simple-scan is unable to open
    simple-scan.log.
  + Fix scanning on Epson devices, when Automatic Page Size is
    enabled.
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.3:
  + Improve compression scale which appear during file saving, to
    be more intuitive.
- Changes from version 3.37.2:
  + Store save directory as URI.
- Changes from version 3.37.1:
  + Show ruler around page.
  + Use default quality setting to prevent slow scanning.
  + Always set brightness and contrast settings to fix bugs with
    the wrong values being used.
  + Redetect scanners when document restarted to fix network
    scanner detection.
  + Small fixes to home page.
  + Display dialog if out of memory.
  + Updated translations.
* Fri Sep  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.6:
  + Display error message if simple-scan is unable to open
    simple-scan.log
  + Fix scanning on Epson devices, when Automatic Page Size is
    enabled.
* Fri Jul 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.4:
  + Fix color scanning for Brother ADS 2200 and 2700 sane backend.
  + Updated translations.
* Wed Jun  3 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.3:
  + Change the size of the paper to avoid visual glitches.
  + Disable possibility of scanning if no device is found, to avoid
    unnecessary errors.
* Wed May  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2.1:
  + Revert the higher bit depth text scans changes - they aren't
    working with PDF saving.
* Tue Apr 28 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Use higher bit depth on text scans.
  + Fix size of first page on second scan.
  + Don't interrupt scanning if the device is busy.
  + Support saving files to FUSE file systems.
  + Update known USB scanner IDs.
  + Add initial Lexmark printers support.
  + Add ADF duplex support for Brother DS-720.
  + Fix setting source for Epson scanner.
* Thu Mar 26 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Stop disabling compression to fix slow scanning.
* Fri Mar  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Updated translations.
* Thu Feb 27 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.35.92:
  + Updated translations.
* Fri Feb 14 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + Improve description in desktop file / AppStream data.
  + Fix page shortcuts no longer working.
  + Help improvements.
* Fri Feb 14 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.90:
  + Fix mnemnonics in preferences dialog.
  + Help improvements.
- Changes from version 3.35.3:
  + Move the scanner selection combo from preferences to the home
    page.
  + Add print option to burger menu.
  + Add preferences button in scan options popover.
  + Remember last Scan type between runs.
  + Move spinner from scan page to scan/stop button.
  + Move preferences location in burger menu.
  + Make scan/stop button change label immediately when it is
    clicked.
  + Adjust minimum size of scan/stop button to better handle
    translations.
  + Add prompt to autoload data to avoid bad data making startup
    impossible.
  + Display an error when no documents found in an ADF scan.
  + Improve handling and debugging of inactive SANE options.
  + Add support for setting brightness and contrast in FIXED
    format.
  + Fix color scanning on some Brother scanners.
  + Fix preferences mnemonics.
  + Set minimal width and height of the main window.
  + Help improvements.
- Changes from version 3.35.2:
  + Updated translations
- Changes from version 3.35.1:
  + Enhance appdata with more fields used by GNOME Software,
    Flathub etc.
  + Update libwepmix VAPI file to fix possibly unassigned local
    variable.
  + Updated translations.
* Thu Feb 13 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.4:
  + Fix page shortcuts no longer working.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Nov 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Updated translations.
* Sun Oct  6 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + libwepmix: Fix use of possibly unassigned local variable
    'data'.
  + Updated translations.
- Drop simple-scan-Fix-use-unassigned-local-variable.patch: Fixed
  upstream.
* Mon Sep 16 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add simple-scan-Fix-use-unassigned-local-variable.patch:
  libwepmix: Fix use of possibly unassigned local variable 'data'.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Fri Sep  6 2019 Chingkai Chu <qkzhu@suse.com>
- Update to version 3.33.92:
  + Updated translations.
- Changes from version 3.33.91:
  + Updated translations.
- Changes from version 3.33.90:
  + Change (user visible) name to "Document Scanner".
  + Updated icon.
- Changes from version 3.33.4:
  + Reinstate shortcut keys that stopped working in 3.32.
  + Fix page delay preferences not working correctly.
- Changes from version 3.33.3:
  + Updated translations.
- Changes from version 3.33.2:
  + Make icon landscape.
- Changes from version 3.33.1:
  + Use new app icon.
* Tue May  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2.1:
  + Updated translations.
* Wed Apr 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + New application icon.
* Tue Apr  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Mon Mar  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Updated translations.
* Tue Feb 19 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Fix save overwriting existing file when user decided not to.
  + Make save button insensitive while saving.
* Thu Feb 14 2019 bjorn.lie@gmail.com
- Update to version 3.31.90.1:
  + Fix crash when detecting scanners.
- Changes from version 3.31.90:
  + Support non-standard Epson ADF scanner options.
* Tue Jan  8 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Updated translations.
- Drop adwaita-icon-theme BuildRequires and old workaround for icon
  brpcheck. No longer needed.
* Thu Jan  3 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Updated translations.
- Changes from version 3.31.2:
  + Use Gtk.FileChooserNative for save dialog so works in sandboxed
    environments.
  + Use GLib.List.deep_copy() to fix type-argument mismatch.
- Changes from version 3.31.1:
  + Replace scan menu with a popdown.
  + Make ActionBar buttons wide to match design.
  + Drop legacy toolbar support.
* Tue Oct 23 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Updated translations.
* Fri Sep 28 2018 bjorn.lie@gmail.com
- Update to version 3.30.1.1:
  + Rebuild tarball as 3.30 releases have out of date content.
  + Update homepage from Launchpad to gitlab.gnome.org.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Updated translations.
- Changes from version 3.30.0:
  + Keep scanning while pages are reordered.
  + Update README.
* Tue Aug 28 2018 bjorn.lie@gmail.com
- Update to version 3.29.92:
  + Keep scanning while pages are reordered.
  + Update README.
  + Updated translations.
* Mon Aug 13 2018 bjorn.lie@gmail.com
- Update to version 3.29.91:
  + Updated translations.
* Mon Jul 30 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Updated translations.
* Fri Jul 13 2018 luc14n0@linuxmail.org
- Update to version 3.29.4:
  + Add A3 paper size to preferences.
  + Remove app menu and add menu into headerbar.
  + Updated translations.
* Sun Jun 17 2018 bjorn.lie@gmail.com
- Update to version 3.29.3:
  + Handle NO_DOCS response during sane_read calls.
* Tue May 22 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + No visible changes for the user.
- Drop conditional use of gnome-icon-theme BuildRequires meant for
  old releases.
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Updated translations.
* Tue Mar 13 2018 luc14n0@linuxmail.org
- Update to version 3.28.0:
  + Updated translations.
- Drop update-desktop-files BuildRequires and its macro: they are
  no longer required.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Feb 21 2018 dimstar@opensuse.org
- Update to version 3.27.91:
  + Update Snap packaging.
* Sat Feb  3 2018 luc14n0@linuxmail.org
- Update to version 3.27.90:
  + Fix email sending failing with PDF attachments.
  + Fix time units for page delay.
  + Updated translations.
* Thu Jan 25 2018 zaitor@opensuse.org
- Update to version 3.27.4:
  + Updated translations.
* Thu Jan 25 2018 luc14n0@linuxmail.org
- Update to version 3.27.3:
  + Updated documentation.
- Update Url to https://gitlab.gnome.org/GNOME/simple-scan: current
  Simple-Scan's web page.
- Add gmodule-export-2.0 and gthread-2.0 pkgconfig modules
  BuildRequires. Note that they were being pulled with other
  pkgconfig modules that live in glib2-devel and used already.
* Thu Jan 25 2018 luc14n0@linuxmail.org
- Update to version 3.27.2:
    + Updated translations.
- Remove %%clean section as it is no longer needed since RPM does
  this job by itself.
* Thu Jan 25 2018 aplazas@suse.com
- Update to version 3.27.1:
  + Explicitly turned off symlink_media to prevent dangling
    symlinks.
  + Dropped obsolete desktop type property in appdata.
  + Moved appdata to a new location.
  + Fixed typos.
  + Updated translations.
* Mon Jan 22 2018 bjorn.lie@gmail.com
- Update to version 3.26.3:
  + Fix email sending failing with PDF attachments.
* Sun Nov  5 2017 luc14n0@linuxmail.org
- Update to version 3.26.2:
  + Updated translations.
- Add pkgconfig(glib-2.0) BuildRequires: new dependency.
- Drop %%glib2_gsettings_schema_*, %%desktop_database_*,
  %%icon_theme_cache_* post(un) scriplets and
  %%glib2_gsettings_schema_requires macro: the functionality now is
  covered by file triggers.
- Drop libjpeg-devel BuildRequires as it's no longer needed/used.
* Thu Oct  5 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Updated translations.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Tue Sep  5 2017 luc14n0@linuxmail.org
- Update to version 3.25.92:
  + Updated translations.
* Mon Aug 21 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Added Snap packaging.
  + Updated translations.
* Mon Aug  7 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Fix grammar in preferences dialog.
* Mon Jul 17 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Add a shortcut window.
  + Fix application ID to match resources names.
* Thu Jun 22 2017 zaitor@opensuse.org
- Update to version 3.25.3:
  + Add support for lossy webp image.
  + More preferences dialog design improvements.
  + Make saving asyncronous, multithreaded, cancellable.
  + Add colour to scan button.
  + Put email entry in hamburger menu (was removed in design
    changes).
  + Don't show welcome page if autloaded document.
  + Fix scan menu not working Unity/XFCE/MATE etc.
  + Don't use headerbar on i3 desktop.
  + Set a minimal version number for packagekit-glib2.
  + Translatable string / build rules improvements.
- Add optional pkgconfig(libwebp) and pkgconfig(libwebpmux)
  BuildRequires: Build webp support.
* Mon May 22 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Redesign preferences dialog.
  + Move JPEG compression control to save dialog.
  + Replace blank page with a homescreen that shows scanner status.
  + Simplify header bar controls.
  + Move page controls to an action bar below scanned page.
  + Improve algorithm that picks JPEG or zlib compression for PDF
    files.
  + Restrict image file filter to supported image formats.
  + Fix compilation with Vala 0.36.
  + Remove obsolete code.
- Changes from version 3.25.1:
  + Check if files exist in multi-file saves.
  + Remove "Save As" - save now always prompts when overwriting.
  + Add a continuous scan option.
  + Make email and print actions insensitive when document empty.
  + Remove .ps and .tiff output support - this is not required.
  + Switch from autotools to Meson.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
* Thu May 11 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Fix compilation with Vala 0.36.
* Fri Mar 24 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + No changes, version bump only.
* Wed Feb 22 2017 zaitor@opensuse.org
- Update to version 3.23.90:
  + Updated translations.
* Thu Dec 29 2016 zaitor@opensuse.org
- Update to version 3.23.3:
  + Updated translations.
- Changes from version 3.23.2:
  + Add optional tags in PDF output to be more PDF/A compliant.
  + Don't use GtkHeaderBar in Cinnamon.
* Sun Sep 25 2016 antoine.belvire@opensuse.org
- Update to version 3.22.0.1:
  + Stop icon name in .desktop file being translated.
- Changes from version 3.22.0:
  + Updated translations.
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Fix typo in warning.
  + Drop X-GNOME-Gettext-Domain.
  + Stop using intltool.
  + Updated translations.
- Drop intltool BuildRequires following upstream changes.
* Sun May  1 2016 zaitor@opensuse.org
- Update to version 3.21.1:
  + Updated translations.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Mar 21 2016 badshah400@gmail.com
- Update to version 3.20.0:
  + Fix window state saving with client side decorations.
- Changes from version 3.19.92:
  + Updated translations.
* Wed Mar  9 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Updated translations.
* Thu Feb 18 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Updated translations.
* Thu Feb 18 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Updated translations.
* Thu Feb 18 2016 dimstar@opensuse.org
- Update to version 3.19.3:a
  + Fix typo in Epson website.
  + Updated translations.
* Thu Feb 18 2016 dimstar@opensuse.org
- Update to version 3.19.2:
  + Make colord/packagekit support able to be explicitly disabled.
* Thu Feb 18 2016 dimstar@opensuse.org
- Update to version 3.19.1:
  + Add help about quality, brightness, contrast settings.
  + Fix help references to Wikipedia (currently just say Wiki).
  + Fix SANE capability logging commas.
* Wed Feb 17 2016 eshmarnev@suse.com
- Update to version 3.18.2:
  + Fix Wrong Epson URL.
  + Fix an issue with choosing of optional dependencies.
* Fri Nov  6 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Make PackageKit support optional.
* Tue Sep 22 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + Show error message when fail to install drivers.
  + Bump copyright dates.
* Thu Sep 17 2015 zaitor@opensuse.org
- Update to version 3.17.92:
  + Correctly select the previous device after the device list is
    updated.
  + Updated translations.
* Mon Sep  7 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Wed Aug 26 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Default to PDF when saving in all cases.
  + Always show file format options and use a combo box to fit
    better into dialog.
  + Detect HP scanners and install drivers using PackageKit if
    found.
  + If SANE detects no scanners but we see USB IDs of Brother,
    Epson or Samsung scanners then prompt the user to go to their
    website to install drivers.
  + Use GUsb instead of GUdev.
  + Fix error dialogs not showing.
- Add pkgconfig(packagekit-glib2) BuildRequires: New dependency.
- Replace pkgconfig(gudev-1.0) for pkgconfig(gusb) following
  upstream changes.
* Sun Aug 16 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Updated translations.
* Sun Jul 19 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Stop using gnome-common, use autotools directly.
* Wed May 27 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Updated translations.
* Wed May 27 2015 zaitor@opensuse.org
- Update to version 3.17.1.1:
  + Build appdata in a separate directory so it can have
    translations merged in but gschemas do not.
* Wed May 27 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Make appdata translatable and add screenshot.
* Wed May 27 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Make appdata translatable and add screenshot (lp#1254913).
* Sun Apr 19 2015 zaitor@opensuse.org
- Update to version 3.16.1.1:
  + Fix logic for adding blank page on page removal.
- Changes from version 3.16.1:
  + Fix save button being inactive on pages restored after a crash.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0.1:
  + Rebuild package from scratch to fix invalid po/Makefile.in.in.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
- Changes from version 3.15.90:
  + Don't use GtkHeaderBar in LXDE, MATE.
* Tue Jan 27 2015 zaitor@opensuse.org
- Update to version 3.15.4:
  + Discards document when pressing ESC in "Save current document?"
    dialog.
  + Show normal menus+window-decos instead of GtkHeaderBars in
    Xfce.
  + Needs X server for --help, --version.
  + Add missing GenericName.
  + Updated translations.
* Sun Jan 18 2015 sfalken@opensuse.org
- Update to version 3.15.3:
  + Updated translations.
- Changes from version 3.15.2:
  + Store density information in bitmap formats (JPEG, PNG, TIFF).
  + Requires gdk-pixbuf 2.32.2.
- Changes from version 3.15.1:
  + Updated translations.
* Sun Sep 21 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + No changes since 3.13.92, stable release.
- Changes from version 3.13.92:
  + Updated translations.
* Sat Aug 30 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Updated translations.
- Changes from version 3.13.90:
  + Duplex scanning from Brother MFC-8910DW ADF does not work
    (lp#1343773).
  + Duplex support for HP Printers/Scanners (lp#1353599).
  + Updated translations.
* Sat Aug  9 2014 dimstar@opensuse.org
- Update to version 3.13.4.2:
  + Fix scan menu not working in toolbar.
  + Fix warning about button that was trying to set both a label
    and an image.
  + Stop warning when no autosave information.
- Changes from version 3.13.4.1:
  + Don't access a variable after ownership is transferred - was
    breaking scans.
  + Fix some UI objects not being accessed since GtkTemplate
    changes.
  + Correct method signature for delete-event.
- Changes from version 3.13.4:
  + Stop configure if vala not found.
  + Make conditions where traditional menubar is shown more
    contrained so it shows in elementary.
  + Use GtkTemplate (requires Vala 0.22).
- Changes from version 3.13.3:
  + Use GtkHeaderbar on systems that support it.
- Changes from version 3.13.1:
  + Correct generation of PDF trailer to conform to the PDF
    standard.
  + Add options to reorder pages.
* Sun Jul 13 2014 dimstar@opensuse.org
- Use Adwaita-icon-theme on openSUSE 13.2 (GNOME 3.14):
  gnome-icon-theme merged the multiple subpackages and was renamed
  to adwaita-icon-theme. The presence of the icon is responsibility
  of GTK 3.
* Tue Apr  1 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + No changes from version 3.11.92.
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Tue Mar  4 2014 zaitor@opensuse.org
- Update to version 3.11.91:
  + Updated translations.
* Tue Feb  4 2014 zaitor@opensuse.org
- Update to version 3.11.5:
  + Only update gsettings when they change. Move application state
    from gsettings to ~/.cache.
* Sun Jan 19 2014 zaitor@opensuse.org
- Update to version 3.11.4:
  + Use AppMenu in GNOME Shell.
* Thu Dec 19 2013 zaitor@opensuse.org
- Update to version 3.11.3:
  + Remove deprecated Gtk.Stock items and Gtk widgets (GtkVBox,
    GtkTable, GtkHButtonBox).
  + Stop using sqlite package.
  + Update .ui file to work with recent Glade version.
  + Fix regression where quality and contrast can be reset to
    minimum.
  + Mark autosaved books as needs saving.
* Thu Dec 19 2013 zaitor@opensuse.org
- Update to version 3.10.2:
  + Install missing help images (lp#1211148).
- Changes from version 3.10.1:
  + Fix page size not being applied on some drivers (lp#550856).
  + Rewrite autosaving. Now uses files for scan data, is more
    efficient in writing to disk and drops dependency on sqlite
    (lp#1245678).
- Drop pkgconfig(sqlite3) BuildRequires, no longer needed.
* Sat Sep 28 2013 zaitor@opensuse.org
- Update to version 3.10.0:
  + Fix --fix-pdf not working due to attempting to treat binary
    data as UTF-8.
* Tue Sep  3 2013 zaitor@opensuse.org
- Update to version 3.9.91:
  + Add appdata file.
* Mon Aug 26 2013 zaitor@opensuse.org
- Update to version 3.9.90:
  + Only autosave after a timeout.
- Changes from version 3.9.4.1:
  + Add missing gresource file to tarball.
- Changes from version 3.9.4:
  + Add support for Samsung devices that don't use the standard
    SANE field names.
- Changes from version 3.9.3:
  + Update README to mention git mirror.
  + Hide C warnings.
  + Compile with Vala debugging information.
- Changes from version 3.9.2:
  + Force an extension when saving if one not provided.
  + Zero pad numbering when saving multiple files.
  + Add JPEG quality settings.
  + Set ICC profile and density units for JPEG files.
  + Use gdk-pixbuf instead of libjpeg when writing PDF files.
- Changes from version 3.9.1:
  + Add copy to clipboard function.
  + Compile UI files into binary.
  + Update build instructions.
- Drop hack to move localized help files into -lang subpackage, not
  needed anymore.
* Fri Mar 29 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + No changes since version 3.7.1.
- Changes from version 3.7.1:
  + Autosave document and restore on quit.
  + Add controls for brightness and contrast.
  + Use GLib 2.32 threading API.
  + Updated help.
  + Simplify build system.
- Add pkgconfig(sqlite3) BuildRequires: new dependency.
* Sun Mar 24 2013 zaitor@opensuse.org
- Update to version 3.6.1:
  + Fix scan no longer working after an ADF scan completes
    (lp#1097096).
  + Fix erroneous warning about failing to set ADF source.
* Fri Jan  4 2013 glin@suse.com
- Update to version 3.6.0:
  + Remove drag and drop support - it breaks the cropping
  + Fix crash caused by signal being emitted in scan thread
  + Fix crash when starting a new document during a scan
  + Fix --debug not working
  + Always set scanner options in the same order to avoid options
    resetting options already set.
  + Number multiple page documents from 1
  + Fix help not working
  + Show progress dialog when saving files
  + Support drag and drop
* Sat Mar 17 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Fix buffer overrun writing black and white PDFs.
  + Build help with yelp-tools instead of gnome-doc-utils.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstream switch.
- Correctly mark translated documentation with %%lang() tags; this
  will be done by %%find_lang shortly in Factory, but not for old
  releases.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Fix JPEG compression not working in PDF files
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + No change, just a version bump.
* Mon Sep 12 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Fix compilation with latest Vala
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Fix incorrect PDF generation, and add a --fix-pdf command line
    to fix broken files generated by older versions
- Changes from version 3.1.5:
  + Fix compile warnings
- Drop simple-scan-gpointer.patch: fixed upstream.
* Wed Aug  3 2011 vuntz@opensuse.org
- Remove unneeded pkgconfig(gconf-2.0) BuildRequires.
- Add pkgconfig(cairo) and pkgconfig(gdk-pixbuf-2.0) BuildRequires,
  which were implicit before.
* Fri Jul 15 2011 nmarques@opensuse.org
- Update to version 3.1.3:
  + Port to Vala
  + Port to GTK+ 3
  + Port to GDBus
  + Port to GSettings
  + Port to colord
- Move to pkgconfig()-style BuildRequires, as well as move to
  GTK+ 3 technologies at the same time:
  + Old ones: glib2-devel, gtk2-devel, gconf2-devel,
    libgudev-1_0-devel.
  + New ones: gconf-2.0, gtk+-3.0, gudev-1.0.
- Add pkgconfig(colord) BuildRequires, for new dependency.
- Add fdupes BuildRequires and call %%fdupes in %%install.
- Remove support for openSUSE 11.3 and earlier, as GTK+ 3 is
  required anyway.
- Removed --disable-static from %%configure as it is not existing.
- Add simple-scan-gpointer.patch: fix assignment in the threading
  code of gboolean to gpointer variables.
- Use %%glib2_gsettings_schema_* macros.
* Wed May  4 2011 dimstar@opensuse.org
- Update to version 2.32.0.2:
  + Add binary comment as recommended in PDF spec
  + Add comments about other PDF/A features
  + Updated translations.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
-
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Fri Oct 22 2010 vuntz@opensuse.org
- Update to version 2.32.0.1:
  + Fix crash when pages not scanned top to bottom
  + Fix PDF output in locales that use ',' for a decimal point
  + Handle grayscale mode in brother3 driver
  + Fix wrong size crop when saving
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Wed Sep 15 2010 aj@suse.de
- Change sane-backends BuildRequires to sane-backends-devel on 11.4
  and later, after the devel split.
* Mon Aug 30 2010 dimstar@opensuse.org
- Update to version 2.31.91:
  + Allow pages to be reordered.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 2.31.90.2:
  + Fix crash saving cropped pages
- Changes from version 2.31.90.1:
  + Store scanned pages in raw format, not converted to 8 bit RGB.
  + Fix scaling in output PDF
  + Use 4 gray levels for text scanned documents
- Changes from version 2.31.90:
  + Updated translations.
- Changes from version 2.31.5:
  + Prompt user to save if they are quitting/starting a new
    document and have unsaved changes.
  + Save button only sensitive if have unsaved data
  + Add save as button
- Changes from version 2.31.4:
  + Implement PDF writer, no longer require ImageMagick and about
    twice as compressed as old method.
- Changes from version 2.31.3:
  + Use GtkInfoBar for errors/warnings
  + Updated translations.
- Remove ImageMagick recommends.
- Add pkgconfig(zlib) and libjpeg-devel BuildRequires.
* Mon Aug  9 2010 vuntz@opensuse.org
- Update to version 2.31.1:
  + Compile with -DGSEAL_ENABLE
  + Fix crash setting automatic source on some drivers
  + Set resolution on ImageMagick generated PDFs
  + Set "duplex" and "batch-scan" flags if supported by driver
- Changes from version 1.0.0:
  + Don't put dashes in temporary filenames used when emailing to
    workaround a Thunderbird bug
  + Add 32x32 crop icon
  + Don't replace scanner provided on the command-line with
    detected devices
  + Handle ImageMagick process failing
  + Fix incorrect dimensions for A4 and A6 paper
* Fri Apr  9 2010 vuntz@opensuse.org
- Update to version 0.9.10:
  + Change default scan direction to top-to-bottom
  + Call sane_cancel after each document, not duing multi page
    scans
  + Set X-GNOME-Gettext-Domain in .desktop file
  + Fix memory leak in page_set_scan_area()
  + Fix read buffering when reading large images
  + Fix moving crop on pages after first
  + Load color profiles for scanner and save them in output files
  + Fix broken logic in picking nearest supported scan resolution
  + Add save button back into toolbar
  + Put text beside crop toolbutton
  + Merge document type into scan menu
* Fri Apr  2 2010 vuntz@opensuse.org
- New package.
